@@ -1,6 +1,6 @@
 import json
 
-from log.loger import loger
+from awesomeTaskPy.log.loger import loger
 import sys
 contextObj=None
 class Singleton(object):
