@@ -1,6 +1,10 @@
+# encoding: utf-8
 import importlib
-from awesomeTaskPy.context import context
+import awesomeTaskPy
+from awesomeTaskPy.context.context import context
 import time
+import sys
+import traceback
 
 
 class baseTask():
@@ -30,23 +34,30 @@ class baseTask():
                 "result": res,
                 "error":None
             }
-            # صֵ־
-            context.context.getContext().getLoger().writeRes(output).flushTmpLog()
-        except Exception as e:
+            # 回调返回值并且情况缓冲的日志
+            awesomeTaskPy.context.context.getContext().getLoger().writeRes(output).flushTmpLog()
+        except:
+            #traceback.print_exc()  # 打印异常信息
+
+            exc_type, exc_value, exc_traceback = sys.exc_info()
+            error = str(repr(traceback.format_exception(exc_type, exc_value, exc_traceback)))  # 将异常信息转为字符串
             output = {
                 "startAt": self.__startAt,
                 "endAt": self.__now(),
                 "runTime": self.__nowInt() - self.__startAtTime,
                 "result": None,
-                "error": e
+                "error":str(error)
             }
-            # صֵ־
-            context.context.getContext().getLoger().writeRes(output).flushTmpLog()
+            # 回调返回值并且情况缓冲的日志
+            awesomeTaskPy.context.context.getContext().getLoger().writeRes(output).flushTmpLog()
     def log(self, message):
-        return context.context.getContext().getLoger().write(message)
+        return  awesomeTaskPy.context.context.getContext().getLoger().write(message)
 
-    # Ĵʵ߼
+    # 具体的代码实现逻辑
     def __run(self):
-        input = self.__taskInfo['input']
+        if "input" in self.__taskInfo.keys():
+            input = self.__taskInfo['input']
+        else:
+            input=[]
         res = importlib.import_module(self.__modulePath).run(*input)
         return res
